% epsilon/calc_all Calculates the mean profiles of epsilon over a
% number of RHI sequences, and plots the result as a time-height
% section.

% the numbers below define the start and end of each collection of
% scans. note that to get the number of, say, raster 3, scan 2, find
% it using danplot, then look at the value of the num variable.

nums_min=[1, 22,43,64,85, 106,127,150];
nums_max=[20,41,62,83,104,125,146,168];
z_offset=[0  0  0  0  0   0   0   0  ];

num_seq=length(nums_min);

if 1 % change this to either calculate the data, or load it from a
     % previous go
	clear mean_times;
	for count=1:num_seq
		
		num_min=nums_min(count);
		num_max=nums_max(count);
		
		autoplot; % do some calculations
		mean_times(count)=mean(all_times);
		index=find(isnan(eps_all));
		eps_all(index)=0;
		weight_all(index)=0;
		if (count == 1)
			mean_eps=sum(eps_all.*weight_all)./sum(weight_all);
			mean_weight=sum(weight_all);
		else
			mean_eps(count,:)=sum(eps_all.*weight_all)./sum(weight_all);
			mean_weight(count,:)=sum(weight_all);
			figure(50)
			clf
			pcolor(mean_times,zr-dz/2,log10(mean_eps'));
			shading interp;
			colorbar;
			hold on
			clear ph;
			for count=1:length(mean_times)
				ph(count)=plot([mean_times(count) mean_times(count)],[0 max(zr)],':');
			end
			%plot the weights
			figure(51)
			clf
			pcolor(mean_times,zr-dz/2,mean_weight');
			shading interp;
			colorbar;
		end
		
	end
else
	disp('Loading data in from file...')
	load calc_all_30km_slope_mask_correct.mat
end

figure(50)
clf
pcolor(mean_times,zr,log10(mean_eps'))
shading interp
xlabel('Time (UTC)')
ylabel('Height (km)')
title('Time-height section of \epsilon')
hold on
caxis([-3.6 -2])
colorbar
clear ph;
for count=1:length(mean_times)
	ph(count)=plot([mean_times(count) mean_times(count)],[0 max(zr)],':');
end
hold on
[c,h]=contour(mean_times,zr,mean_weight','k');
clabel(c,h,'labels',288) 

[t1,z1]=meshgrid(min(mean_times):0.02:max(mean_times),min(zr):0.05:max(zr));
eps1=interp2(mean_times,zr,mean_eps',t1,z1,'linear');

figure(53)
clf
%pcolor(t1,z1,real(log10(eps1)));shading flat;caxis([-3.6 -2]);colorbar

[c,h,cf]=contourf(t1,z1,real(log10(eps1)),[-3.8:.1:-2.5],'w');
clabel(c,h,'labels',288) 
xlabel('Time (UTC)')
ylabel('Height (km)')
title('Time-height section of Log_{10}(\epsilon)')
hold on
clear ph;
for count=1:length(mean_times)
	ph(count)=plot([mean_times(count) mean_times(count)],[0 max(zr)],':');
end
hold on
%[c,h]=contour(mean_times,zr,mean_weight','k');
%clabel(c,h,'labels',288) 

colorbar
%axis([6 15 0 5]);set(gca,'position',[.1,.25,.8,.65]);set(gcf,'paperunits','centimeters','paperposition',[2,8,17,17]);
set(gca,'xdir','rev')

figure(51)
clf
pcolor(mean_times,zr-dz/2,mean_weight')
xlabel('Time (UTC)')
ylabel('Height (km)')
title('Time-height section of the weights for the \epsilon plot')
hold on
clear ph;
for count=1:length(mean_times)
	ph(count)=plot([mean_times(count) mean_times(count)],[0 max(zr)],':');
end

figure(52)
clf
st={'ro-','gx-','b+-','m*-','ks-','cd-','ro--','gx--','b+--','m*--','ks--','cd--','ro:','gx:','b+:','m*:','ks:','cd:'}
legs={'1','2','3','4','5','6','7','8','9','10','11','12','13','14'}
for i=1:length(mean_times)
	semilogx(mean_eps(i,:),zr,st{i})
	hold on
	drawnow
end
legend(legs,0)
title(['\epsilon (xmax=' num2str(xmax) ')'])
ylabel('Height(km)')
xlabel('Log_{10} (\epsilon)')

