%STREAMMENU: Creates a widget used for deriving/plotting streamlines etc

%zmin=0;zmax=5;shmin=-10;shmax=10
%look at inputdlg and uimenu

if exist('boundz')==0
	xrmin=10;xrmax=50;dxr=0.25;
	zrmin=zmin;zrmax=zmax;dzr=0.1;
	backspeed=0;
	numnan=40;
	smoothing=0.4;
	trace=1;
	boundz=0.1;
	overlay=0;
end

ground=1;
underlay=1;

DX=40;
DY=22;
YTOP=DY*9;

h=findobj('name','Streamline menu');
if ~isempty(h)
	delete(h)
end
streammenuh=figure('numbertitle','off','resize','off','name','Streamline menu','units','pix','position',[0,0,DX*8,YTOP+DY],'IntegerHandle','off');

uicontrol('style','text','position',[0,YTOP,3*DX,DY],'string','xmin, dx, xmax:','fontsize',12,'tooltip','Grid to interpolate onto');
xrminh=uicontrol('Style','edit','Position',[3*DX,YTOP,2*DX,DY],'string',num2str(xrmin),'callback','xrmin=str2num(get(xrminh,''string''))','back','w','fontsize',12);
dxrh=uicontrol('Style','edit','Position',[5*DX,YTOP,DX,DY],'string',num2str(dxr),'callback','dxr=str2num(get(dxrh,''string''))','back','w','fontsize',12);
xrmaxh=uicontrol('Style','edit','Position',[6*DX,YTOP,2*DX,DY],'string',num2str(xrmax),'callback','xrmax=str2num(get(xrmaxh,''string''))','back','w','fontsize',12);

uicontrol('style','text','position',[0,YTOP-DY,3*DX,DY],'string','zmin, dz, zmax:','fontsize',12,'tooltip','Grid to interpolate onto');
zrminh=uicontrol('Style','edit','Position',[3*DX,YTOP-DY,2*DX,DY],'string',num2str(zrmin),'callback','zrmin=str2num(get(zrminh,''string''))','back','w','fontsize',12);
dzrh=uicontrol('Style','edit','Position',[5*DX,YTOP-DY,DX,DY],'string',num2str(dzr),'callback','dzr=str2num(get(dzrh,''string''))','back','w','fontsize',12);
zrmaxh=uicontrol('Style','edit','Position',[6*DX,YTOP-DY,2*DX,DY],'string',num2str(zrmax),'callback','zrmax=str2num(get(zrmaxh,''string''))','back','w','fontsize',12);

uicontrol('style','text','position',[0,YTOP-2*DY,4*DX,DY],'string','Backspeed to subtract from -vu :','fontsize',12,'tooltip','Type ''help streamcalc'' for details on this highly confusing parameter!');
backh=uicontrol('Style','edit','Position',[4*DX,YTOP-2*DY,2*DX,DY],'string',num2str(backspeed),'callback','backspeed=str2num(get(backh,''string''))','back','w','fontsize',12);

uicontrol('style','text','position',[0,YTOP-3*DY,4*DX,DY],'string','Replace NaNs num times :','fontsize',12,'tooltip','How many times to ''fill in'' the regions of no data');
numh=uicontrol('Style','edit','Position',[4*DX,YTOP-3*DY,2*DX,DY],'string',num2str(numnan),'callback','numnan=str2num(get(numh,''string''))','back','w','fontsize',12);

uicontrol('style','text','position',[0,YTOP-4*DY,4*DX,DY],'string','Smoothing factor :','fontsize',12);
smoothh=uicontrol('Style','edit','Position',[4*DX,YTOP-4*DY,2*DX,DY],'string',num2str(smoothing),'callback','smoothing=str2num(get(smoothh,''string''))','back','w','fontsize',12);

uicontrol('style','text','position',[0,YTOP-5*DY,4*DX,DY],'string','Shear shading range : ','fontsize',12);
shminh=uicontrol('Style','edit','Position',[4*DX,YTOP-5*DY,2*DX,DY],'string',num2str(shmin),'callback','shmin=str2num(get(shminh,''string''))','back','w','fontsize',12);
shmaxh=uicontrol('Style','edit','Position',[6*DX,YTOP-5*DY,2*DX,DY],'string',num2str(shmax),'callback','shmax=str2num(get(shmaxh,''string''))','back','w','fontsize',12);

uicontrol('style','text','position',[0,YTOP-6*DY,6*DX,DY],'string','Attempt to force BC at ground : ','fontsize',12,'tooltip','Uses a very slow poisson solver if you choose ''yes''');
groundh=uicontrol('style','popup','position',[6*DX,YTOP-6*DY,2*DX,DY],'string','No|Yes','callback','ground=get(groundh,''value'');','fontsize',12);

uicontrol('style','text','position',[0,YTOP-7*DY,4*DX,DY],'string','Underlay field if tracing:','fontsize',12);
underlayh=uicontrol('style','popup','position',[4*DX,YTOP-7*DY,2*DX,DY],'string','Shear|Velocity|shr|vr|vr2|wr','callback','underlay=get(underlayh,''value'');','fontsize',12,'tooltip','lets you specify one streamline by clicking');
traceh=uicontrol('style','pushbutton','position',[6*DX,YTOP-7*DY,2*DX,DY],'string','Trace...','callback','trace=1;streamtrace;','fontsize',12);

uicontrol('style','text','position',[0,YTOP-8*DY,7*DX,DY],'string','Height of fixed boundary (if not tracing) : ','fontsize',12,'tooltip','Changing this value runs stramcalc');
boundh=uicontrol('Style','edit','Position',[7*DX,YTOP-8*DY,DX,DY],'string',num2str(boundz),'callback','boundz=str2num(get(boundh,''string'')),trace=2;streamtrace;','back','w','fontsize',12);

trace0h=uicontrol('style','pushbutton','position',[0*DX,YTOP-9*DY,2*DX,DY],'string','Calc...','callback','trace=0;streamtrace;','fontsize',12);


over0h=uicontrol('style','pushbutton','position',[2*DX,YTOP-9*DY,3*DX,DY],'string','Preview result...','callback','overlay=0;streamoverlay;','fontsize',12);

over1h=uicontrol('style','pushbutton','position',[5*DX,YTOP-9*DY,3*DX,DY],'string','Overlay result...','callback','overlay=1;tester;','fontsize',12,'tooltip','Overlays result on the output of rhiplot');

set(streammenuh,'handlevis','callback');